@@ -6,8 +6,10 @@
 #'   response, at the margin of specific values from certain model terms,
 #'   where additional model terms indicate the grouping structure.
 #'   \code{ggeffect()} computes marginal effects by internally calling
-#'   \code{\link[effects]{Effect}}. \code{ggaverage()} computes the average
-#'   predicted values. The result is returned as tidy data frame.
+#'   \code{\link[effects]{Effect}}, while \code{ggemmeans()} computes marginal
+#'   effects by internally calling \code{\link[emmeans]{emmeans}}.
+#'   \code{ggaverage()} computes the average predicted values. The result is
+#'   returned as tidy data frame.
 #'
 #' @param model A fitted model object, or a list of model objects. Any model
 #'   that supports common methods like \code{predict()}, \code{family()}
@@ -17,7 +19,7 @@
 #'   from \code{model}, for which marginal effects should be displayed. At least
 #'   one term is required to calculate effects for certain terms, maximum length is
 #'   three terms, where the second and third term indicate the groups, i.e.
-#'   predictions of first term are grouped by the levels of the second (and third)
+#'   predictions of first term are grouped by the values of the second (and third)
 #'   term. If \code{terms} is missing or \code{NULL}, marginal effects for each
 #'   model term are calculated. It is also possible to define specific values for
 #'   terms, at which marginal effects should be calculated (see 'Details').
@@ -28,48 +30,60 @@
 #' @param ci.lvl Numeric, the level of the confidence intervals. For \code{ggpredict()},
 #'   use \code{ci.lvl = NA}, if confidence intervals should not be calculated
 #'   (for instance, due to computation time).
-#' @param type Character, only applies for mixed effects models and/or models
-#'   with zero-inflation.
+#' @param type Character, only applies for survival models, mixed effects models
+#'   and/or models with zero-inflation. \strong{Note:} For \code{brmsfit}-models
+#'   with zero-inflation component, there is no \code{type = "fe.zi"} nor
+#'   \code{type = "re.zi"}; predicted values for \code{MixMod}-models from
+#'   \pkg{GLMMadaptive} with zero-inflation component \emph{always} condition on
+#'   the zero-inflation part of the model (see 'Details').
 #'   \describe{
 #'     \item{\code{"fe"}}{
 #'     Predicted values are conditioned on the fixed effects or conditional
-#'     model only. For instance, for models fitted with \code{zeroinfl} from
-#'     \pkg{pscl}, this would return the predicted mean from the count component
-#'     (without zero-inflation). For models of class \code{glmmTMB}, this type
-#'     calls \code{predict(..., type = "link")}.
+#'     model only (for mixed models: predicted values are on the population-level).
+#'     For instance, for models fitted with \code{zeroinfl} from \pkg{pscl},
+#'     this would return the predicted mean from the count component (without
+#'     zero-inflation). For models with zero-inflation component, this type calls
+#'     \code{predict(..., type = "link")} (however, predicted values are
+#'     back-transformed to the response scale).
 #'     }
 #'     \item{\code{"re"}}{
-#'     Predicted values are conditioned on the random effects. This only applies
-#'     to mixed models, and \code{type = "re"} does not condition on the
-#'     zero-inflation component of the model, nor on different group levels.
-#'     \code{type = "re"} uses the reference level in the random effects groups
-#'     (except for \pkg{glmmTMB} models, see below), and prediction intervals
-#'     also consider the uncertainty in the variance parameters. For models
-#'     from \pkg{glmmTMB}, this type calls \code{predict(..., type = "link")}.
-#'     \strong{Note:} For \pkg{glmmTMB} models, the random effect variances only
-#'     affect the confidence intervals of predictions, not the predicted values
-#'     themselves (because this is currently not implemented in \pkg{glmmTMB}),
-#'     i.e. predicted values are on population-level. To get predicted values
-#'     for each level of the random effects groups, add the name of the related
-#'     random effect term to the \code{terms}-argument (for more details,
-#'     see \href{../doc/effectsatvalues.html}{this vignette}).
+#'     This only applies to mixed models, and \code{type = "re"} does not
+#'     condition on the zero-inflation component of the model. \code{type = "re"}
+#'     still returns population-level predictions, however, unlike \code{type = "fe"},
+#'     prediction intervals also consider the uncertainty in the variance parameters
+#'     (the mean random effect variance, see \cite{Johnson et al. 2014} for details).
+#'     For models with zero-inflation component, this type calls
+#'     \code{predict(..., type = "link")} (however, predicted values are
+#'     back-transformed to the response scale).
+#'     \cr \cr
+#'     To get predicted values for each level of the random effects groups, add the
+#'     name of the related random effect term to the \code{terms}-argument
+#'     (for more details, see \href{../doc/effectsatvalues.html}{this vignette}).
 #'     }
 #'     \item{\code{"fe.zi"}}{
 #'     Predicted values are conditioned on the fixed effects and the zero-inflation
 #'     component. For instance, for models fitted with \code{zeroinfl}
-#'     from \pkg{pscl}, this would return the predicted response and for \pkg{glmmTMB},
-#'     this would return the expected value \code{mu*(1-p)} \emph{without}
-#'     conditioning on random effects. For models of class \code{glmmTMB}, this type
-#'     calls \code{predict(..., type = "response")}.
+#'     from \pkg{pscl}, this would return the predicted response (\code{mu*(1-p)})
+#'     and for \pkg{glmmTMB}, this would return the expected value \code{mu*(1-p)}
+#'     \emph{without} conditioning on random effects (i.e. random effect variances
+#'     are not taken into account for the confidence intervals). For models with
+#'     zero-inflation component, this type calls \code{predict(..., type = "response")}.
+#'     See 'Details'.
 #'     }
 #'     \item{\code{"re.zi"}}{
-#'     Predicted values are conditioned on the random effects and the
-#'     zero-inflation component. For models fitted with \pkg{glmmTMB}, this
-#'     would return the expected value \code{mu*(1-p)}, conditioned on random
-#'     effects. Prediction intervals also consider the uncertainty in the
-#'     variance parameters. For models from \pkg{glmmTMB}, this type
-#'     calls \code{simulate()}, because conditioning on random effects is
-#'     not yet implemented in \code{predict.glmmTMB()}.
+#'     Predicted values are conditioned on the zero-inflation component and
+#'     take the random effects uncertainty into account. For models fitted with
+#'     \code{glmmTMB()}, \code{hurdle()} or \code{zeroinfl()}, this would return the
+#'     expected value \code{mu*(1-p)}. For \pkg{glmmTMB}, prediction intervals
+#'     also consider the uncertainty in the random effects variances. This
+#'     type calls \code{predict(..., type = "response")}. See 'Details'.
+#'     }
+#'     \item{\code{"sim"}}{
+#'     Predicted values and confidence resp. prediction intervals are
+#'     based on simulations, i.e. calls to \code{simulate()}. This type
+#'     of prediction takes all model uncertainty into account, including
+#'     random effects variances. Currently supported models are \code{glmmTMB}
+#'     and \code{merMod}. See \code{...} for details on number of simulations.
 #'     }
 #'     \item{\code{"surv"} and \code{"cumhaz"}}{
 #'     Applies only to \code{coxph}-objects from the \pkg{survial}-package and
@@ -89,15 +103,22 @@
 #'   Usually, this argument is only used internally by \code{ggaverage()}.
 #' @param typical Character vector, naming the function to be applied to the
 #'   covariates over which the effect is "averaged". The default is "mean".
-#'   See \code{\link[sjstats]{typical_value}} for options.
+#'   See \code{\link[sjmisc]{typical_value}} for options.
 #' @param ppd Logical, if \code{TRUE}, predictions for Stan-models are
 #'   based on the posterior predictive distribution
 #'   (\code{\link[rstantools]{posterior_predict}}). If \code{FALSE} (the
 #'   default), predictions are based on posterior draws of the linear
 #'   predictor (\code{\link[rstantools]{posterior_linpred}}).
-#' @param x.as.factor Logical, if \code{TRUE}, preserves factor-class as
-#'   \code{x}-column in the returned data frame. By default, the \code{x}-column
-#'   is always numeric.
+#' @param x.as.factor,x.cat Logical, if \code{TRUE}, preserves factor-class as
+#'   \code{x}-column in the returned data frame (only applies if first variable
+#'   in \code{terms} is a factor). By default, the \code{x}-column is always
+#'   numeric. This argument is useful when building own plots from the data,
+#'   based on ggplot, so you don't need to coerce \code{x} to factor. The
+#'   \code{plot()}-method, however, automatically uses continuous or discrete
+#'   x-scales, depending on the variable-type. For more details, see
+#'   \href{../doc/plotmethod.html}{the plot-vignette} and the
+#'   \href{../doc/marginaleffects.html}{the vignette on package-basics}.
+#'   \code{x.cat} is an alias for \code{x.as.factor}.
 #' @param condition Named character vector, which indicates covariates that
 #'   should be held constant at specific values. Unlike \code{typical}, which
 #'   applies a function to the covariates to determine the value that is used
@@ -117,41 +138,47 @@
 #' @param vcov.args List of named vectors, used as additional arguments that
 #'    are passed down to \code{vcov.fun}.
 #' @param ... For \code{ggpredict()}, further arguments passed down to
-#'    \code{predict()}, and for \code{ggeffect()}, further arguments passed
-#'    down to \code{\link[effects]{Effect}}. If \code{model} is of class
-#'    \code{glmmTMB}, \code{...} may also be used to set the number of
-#'    simulation for bootstrapped confidence intervals, e.g. \code{nsim = 500}.
+#'    \code{predict()}; for \code{ggeffect()}, further arguments passed
+#'    down to \code{\link[effects]{Effect}}; and for \code{ggemmeans()},
+#'    further arguments passed down to \code{\link[emmeans]{emmeans}}.
+#'    If \code{type = "sim"}, \code{...} may also be used to set the number of
+#'    simulation, e.g. \code{nsim = 500}.
 #'
 #' @details
 #'   \strong{Supported Models}
 #'   \cr \cr
-#'   Currently supported model-objects are: \code{lm}, \code{glm}, \code{glm.nb},
-#'   \code{lme}, \code{lmer}, \code{glmer}, \code{glmer.nb}, \code{nlmer},
-#'   \code{glmmTMB}, \code{gam}, \code{vgam}, \code{gamm}, \code{gamm4},
-#'   \code{multinom}, \code{betareg}, \code{gls}, \code{gee}, \code{plm},
-#'   \code{lrm}, \code{polr}, \code{clm}, \code{clm2}, \code{hurdle}, \code{zeroinfl},
-#'   \code{svyglm}, \code{svyglm.nb}, \code{truncreg}, \code{coxph},
-#'   \code{stanreg}, \code{brmsfit}, \code{lmRob}, \code{glmRob}, \code{brglm}
-#'   and \code{rlm}.
+#'   Currently supported model-objects are (in alphabetical order):
+#'   \code{betareg}, \code{brglm}, \code{brmsfit}, \code{clm}, \code{clm2}, \code{clmm},
+#'   \code{coxph}, \code{gam} (package \pkg{mgcv}), \code{Gam} (package \pkg{gam}),
+#'   \code{gamm}, \code{gamm4}, \code{gee}, \code{glm}, \code{glm.nb}, \code{glmer},
+#'   \code{glmer.nb}, \code{glmmTMB}, \code{glmmPQL}, \code{glmRob}, \code{gls},
+#'   \code{hurdle}, \code{ivreg}, \code{lm}, \code{lm_robust}, \code{lme},
+#'   \code{lmer}, \code{lmRob}, \code{lrm}, \code{MixMod}, \code{MCMCglmm},
+#'   \code{multinom}, \code{nlmer}, \code{plm}, \code{polr}, \code{rlm},
+#'   \code{stanreg}, \code{svyglm}, \code{svyglm.nb}, \code{truncreg},
+#'   \code{vgam}, \code{zeroinfl} and \code{zerotrunc}.
 #'   Other models not listed here are passed to a generic predict-function
-#'   and might work as well, or maybe with \code{ggeffect()}, which
-#'   effectively does the same as \code{ggpredict()}. The main difference
+#'   and might work as well, or maybe with \code{ggeffect()} or \code{ggemmeans()},
+#'   which effectively do the same as \code{ggpredict()}. The main difference
 #'   is that \code{ggpredict()} calls \code{predict()}, while \code{ggeffect()}
-#'   calls \code{\link[effects]{Effect}} to compute marginal effects.
+#'   calls \code{\link[effects]{Effect}} and \code{ggemmeans()} calls
+#'   \code{\link[emmeans]{emmeans}} to compute marginal effects.
 #'   \cr \cr
-#'   \strong{Difference between \code{ggpredict()} and \code{ggeffect()}}
+#'   \strong{Difference between \code{ggpredict()} and \code{ggeffect()} or \code{ggemmeans()}}
 #'   \cr \cr
-#'   \code{ggpredict()} and \code{ggeffect()} differ in how factors are
-#'   held constant: \code{ggpredict()} uses the reference level, while
-#'   \code{ggeffect()} computes a kind of "average" value, which represents
-#'   the proportions of each factor's category.
+#'   \code{ggpredict()} and \code{ggeffect()} resp. \code{ggemmeans()} differ in
+#'   how factors are held constant: \code{ggpredict()} uses the reference level, while
+#'   \code{ggeffect()} and \code{ggemmeans()} compute a kind of "average" value,
+#'   which represents the proportions of each factor's category. Use \code{condition}
+#'   to set a specific level for factors in \code{ggemmeans()}, so factors are
+#'   not averaged over their categories, but held constant at a given level.
 #'   \cr \cr
 #'   \strong{Marginal Effects at Specific Values}
 #'   \cr \cr
 #'   Specific values of model terms can be specified via the \code{terms}-argument.
 #'   Indicating levels in square brackets allows for selecting only
-#'   specific groups or values resp. value ranges. Term name and levels in
-#'   brackets must be separated by a whitespace character, e.g.
+#'   specific groups or values resp. value ranges. Term name and the start of
+#'   the levels in brackets must be separated by a whitespace character, e.g.
 #'   \code{terms = c("age", "education [1,3]")}. Numeric ranges, separated
 #'   with colon, are also allowed: \code{terms = c("education", "age [30:60]")}.
 #'   \cr \cr
@@ -166,6 +193,8 @@
 #'   predictions will then be transformed, e.g. \code{terms = "income [exp]"}.
 #'   This is useful when model predictors were transformed for fitting the
 #'   model and should be back-transformed to the original scale for predictions.
+#'   It is also possible to define own functions (see
+#'   \href{../doc/effectsatvalues.html}{this vignette}).
 #'   \cr \cr
 #'   You can take a random sample of any size with \code{sample=n}, e.g
 #'   \code{terms = "income [sample=8]"}, which will sample eight values from
@@ -179,9 +208,9 @@
 #'   memory allocation problems for vectors with many unique values. If a numeric
 #'   vector is specified as second or third term (i.e. if this vector represents
 #'   a grouping structure), representative values (see \code{\link{rprs_values}})
-#'   are chosen. If all values for a numeric vector should be used to compute
-#'   predictions, you may use e.g. \code{terms = "age [all]"}. See also
-#'   package vignettes.
+#'   are chosen (unless other values are specified). If all values for a numeric
+#'   vector should be used to compute predictions, you may use e.g.
+#'   \code{terms = "age [all]"}. See also package vignettes.
 #'   \cr \cr
 #'   To create a pretty range that should be smaller or larger than the default
 #'   range (i.e. if no specific values would be given), use the \code{n}-tag,
@@ -210,42 +239,63 @@
 #'   as calculating marginal effects at the mean, while \code{ggaverage()}
 #'   computes average marginal effects.
 #'   \cr \cr
-#'   \code{ggeffect()}, by default, sets remaining numeric covariates to
-#'   their mean value, while for factors, a kind of "average" value, which
-#'   represents the proportions of each factor's category, is used.
+#'   \code{ggeffect()} and \code{ggemmeans()}, by default, set remaining numeric
+#'   covariates to their mean value, while for factors, a kind of "average" value,
+#'   which represents the proportions of each factor's category, is used. For
+#'   \code{ggemmeans()}, use \code{condition} to set a specific level for
+#'   factors so that these are not averaged over their categories, but held
+#'   constant at the given level.
 #'   \cr \cr
 #'   \strong{Bayesian Regression Models}
 #'   \cr \cr
 #'   \code{ggpredict()} also works with \strong{Stan}-models from
 #'   the \CRANpkg{rstanarm} or \CRANpkg{brms}-package. The predicted
 #'   values are the median value of all drawn posterior samples. The
-#'   confidence intervals for Stan-models are actually high density
-#'   intervals, computed by \code{\link[sjstats]{hdi}}, unless \code{ppd = TRUE}.
-#'   If \code{ppd = TRUE}, predictions are based on draws of the posterior
-#'   predictive  distribution and the uncertainty interval is computed
-#'   using  \code{\link[rstantools]{predictive_interval}}. By default (i.e.
-#'   \code{ppd = FALSE}), the predictions are based on
+#'   confidence intervals for Stan-models are Bayesian predictive intervals.
+#'   By default (i.e. \code{ppd = FALSE}), the predictions are based on
 #'   \code{\link[rstantools]{posterior_linpred}} and hence have some
 #'   limitations: the uncertainty of the error term is not taken into
 #'   account. The recommendation is to use the posterior predictive
 #'   distribution (\code{\link[rstantools]{posterior_predict}}).
-#'   Note that for binomial models, the \code{newdata}-argument
-#'   used in \code{posterior_predict()} must also contain the vector
-#'   with the number of trials. In this case, a dummy-vector is used,
-#'   where all values for the response are set to 1.
 #'   \cr \cr
-#'   \strong{Zero-Inflated Mixed Models with glmmTMB}
+#'   \strong{Zero-Inflated and Zero-Inflated Mixed Models with brms}
 #'   \cr \cr
-#'   If \code{model} is of class \code{glmmTMB}, bootstrapped confidence
-#'   intervals are calculated for predictions conditioned on the zero-inflated
-#'   part of the model, when the uncertainty in the random-effect paramters
-#'   is ignored (i.e. when \code{type = "fe.zi"}, see Brooks et al. 2017, pp.391-392
-#'   for details). \code{type = "fe.zi"} returns predicted values at population
-#'   \emph{mode}, not mean. If predictions are also conditioned on random
-#'   effects (i.e. \code{type = "re.zi"}), predicted values are based on
-#'   simulations (see Brooks et al. 2017, pp.392-393 for details).
+#'   Models of class \code{brmsfit} always condition on the zero-inflation
+#'   component, if the model has such a component. Hence, there is no
+#'   \code{type = "fe.zi"} nor \code{type = "re.zi"} for \code{brmsfit}-models,
+#'   because predictions are based on draws of the posterior distribution,
+#'   which already account for the zero-inflation part of the model.
+#'   \cr \cr
+#'   \strong{Zero-Inflated and Zero-Inflated Mixed Models with glmmTMB}
+#'   \cr \cr
+#'   If \code{model} is of class \code{glmmTMB}, \code{hurdle}, \code{zeroinfl}
+#'   or \code{zerotrunc}, simulations from a multivariate normal distribution
+#'   (see \code{\link[MASS]{mvrnorm}}) are drawn to calculate \code{mu*(1-p)}.
+#'   Confidence intervals are then based on quantiles of these results. For
+#'   \code{type = "re.zi"}, prediction intervals also take the uncertainty in
+#'   the random-effect paramters into account (see also Brooks et al. 2017,
+#'   pp.391-392 for details).
+#'   \cr \cr
+#'   An alternative for models fitted with \pkg{glmmTMB} that take all model
+#'   uncertainties into account are simulations based on \code{simulate()}, which
+#'   is used when \code{type = "sim"} (see Brooks et al. 2017, pp.392-393 for
+#'   details).
+#'   \cr \cr
+#'   \strong{MixMod-models from GLMMadaptive}
+#'   \cr \cr
+#'   Predicted values for the fixed effects component (\code{type = "fe"} or
+#'   \code{type = "fe.zi"}) are based on \code{predict(..., type = "mean_subject")},
+#'   while predicted values for random effects components (\code{type = "re"} or
+#'   \code{type = "re.zi"}) are calculated with \code{predict(..., type = "subject_specific")}
+#'   (see \code{?GLMMadaptive::predict.MixMod} for details). The latter option
+#'   requires the response variable to be defined in the \code{newdata}-argument
+#'   of \code{predict()}, which will be set to its typical value (see
+#'   \code{\link[sjmisc]{typical_value}}).
 #'
-#' @references Brooks ME, Kristensen K, Benthem KJ van, Magnusson A, Berg CW, Nielsen A, et al. glmmTMB Balances Speed and Flexibility Among Packages for Zero-inflated Generalized Linear Mixed Modeling. The R Journal. 2017;9: 378–400.
+#' @references \itemize{
+#'    \item Brooks ME, Kristensen K, Benthem KJ van, Magnusson A, Berg CW, Nielsen A, et al. glmmTMB Balances Speed and Flexibility Among Packages for Zero-inflated Generalized Linear Mixed Modeling. The R Journal. 2017;9: 378-400.
+#'    \item Johnson PC, O'Hara RB. 2014. Extension of Nakagawa & Schielzeth's R2GLMM to random slopes models. Methods Ecol Evol, 5: 944-946. (\doi{10.1111/2041-210X.12225})
+#'  }
 #'
 #' @note
 #'   Since data for \code{ggaverage()} comes from the model frame, not all
@@ -261,9 +311,16 @@
 #'   The \code{print()}-method gives a clean output (especially for predictions
 #'   by groups), and indicates at which values covariates were held constant.
 #'   Furthermore, the \code{print()}-method has the arguments \code{digits} and
-#'   \code{n} to control number of decimals and lines to be printed.
+#'   \code{n} to control number of decimals and lines to be printed, and an
+#'   argument \code{x.lab} to print factor-levels instead of numeric values
+#'   if \code{x} is a factor.
+#'   \cr \cr
+#'   The support for some models, for example from package \pkg{MCMCglmm}, is
+#'   rather experimental and may fail for certain models. If you encounter
+#'   any errors, please file an issue at \url{https://github.com/strengejacke/ggeffects/issues}.
 #'
-#' @return A data frame (with \code{ggeffects} class attribute) with consistent data columns:
+#' @return A data frame (with \code{ggeffects} class attribute) with consistent
+#'   data columns:
 #'         \describe{
 #'           \item{\code{x}}{the values of the first term in \code{terms}, used as x-position in plots.}
 #'           \item{\code{predicted}}{the predicted values of the response, used as y-position in plots.}
@@ -275,10 +332,15 @@
 #'           \item{\code{group}}{the grouping level from the second term in \code{terms}, used as grouping-aesthetics in plots.}
 #'           \item{\code{facet}}{the grouping level from the third term in \code{terms}, used to indicate facets in plots.}
 #'         }
+#'         The predicted values are always on the response scale! \cr \cr
 #'         For proportional odds logistic regression (see \code{\link[MASS]{polr}})
 #'         resp. cumulative link models (e.g., see \code{\link[ordinal]{clm}}),
 #'         an additional column \code{response.level} is returned, which indicates
 #'         the grouping of predictions based on the level of the model's response.
+#'         \cr \cr Note that for convenience reasons, the columns for the intervals
+#'         are always named \code{conf.low} and \code{conf.high}, even though
+#'         for Bayesian models credible or highest posterior density intervals
+#'         are returned.
 #'
 #' @examples
 #' data(efc)
@@ -407,12 +469,12 @@
 #' @importFrom sjmisc to_factor is_num_fac remove_empty_cols
 #' @importFrom purrr map
 #' @importFrom sjlabelled as_numeric
-#' @importFrom sjstats resp_var re_grp_var
+#' @importFrom insight find_random find_predictors model_info find_formula find_variables
 #' @export
 ggpredict <- function(model,
                       terms,
                       ci.lvl = .95,
-                      type = c("fe", "re", "fe.zi", "re.zi", "surv", "cumhaz", "debug"),
+                      type = c("fe", "re", "fe.zi", "re.zi", "sim", "surv", "cumhaz", "debug"),
                       typical = "mean",
                       condition = NULL,
                       ppd = FALSE,
@@ -421,21 +483,25 @@ ggpredict <- function(model,
                       vcov.fun = NULL,
                       vcov.type = NULL,
                       vcov.args = NULL,
+                      x.cat,
                       ...) {
   # check arguments
   type <- match.arg(type)
+  model.name <- deparse(substitute(model))
+
+  if (!missing(x.cat)) x.as.factor <- x.cat
 
   # check if terms are a formula
   if (!missing(terms) && !is.null(terms) && inherits(terms, "formula")) {
     terms <- all.vars(terms)
   }
 
-  # for gamm4 objects, we have a list with two items, mer and gam
+  # for gamm/gamm4 objects, we have a list with two items, mer and gam
   # extract just the mer-part then
-  if (inherits(model, "list") && all(names(model %in% c("mer", "gam")))) {
-    model <- model$mer
-    class(model) <- "lmerMod"
-  }
+  is.gamm <- inherits(model, c("list", "gamm")) && all(names(model %in% c("lme", "gam")))
+  is.gamm4 <- inherits(model, "list") && all(names(model %in% c("mer", "gam")))
+
+  if (is.gamm || is.gamm4) model <- model$gam
 
   if (inherits(model, "list")) {
     res <- purrr::map(model, ~ggpredict_helper(
@@ -456,7 +522,7 @@ ggpredict <- function(model,
     class(res) <- c("ggalleffects", class(res))
   } else {
     if (missing(terms) || is.null(terms)) {
-      predictors <- sjstats::pred_vars(model)
+      predictors <- insight::find_predictors(model, effects = "fixed", component = "conditional", flatten = TRUE)
       res <- purrr::map(
         predictors,
         function(.x) {
@@ -501,13 +567,13 @@ ggpredict <- function(model,
     }
   }
 
+  attr(res, "model.name") <- model.name
   res
 }
 
 
 # workhorse that computes the predictions
 # and creates the tidy data frames
-#' @importFrom sjstats model_frame
 ggpredict_helper <- function(model,
                              terms,
                              ci.lvl,
@@ -525,27 +591,23 @@ ggpredict_helper <- function(model,
   fun <- get_predict_function(model)
 
   # check terms argument
-  terms <- check_vars(terms)
+  terms <- check_vars(terms, model)
   cleaned.terms <- get_clear_vars(terms)
 
   # check if predictions should be made for each group level in
   # random effects models
   if (fun %in% c("lmer", "glmer", "glmmTMB", "nlmer")) {
-    re.terms <- sjstats::re_grp_var(model)
+    re.terms <- insight::find_random(model, split_nested = TRUE, flatten = TRUE)
     if (!is.null(re.terms) && any(cleaned.terms %in% re.terms)) ci.lvl <- NA
   }
 
   # check model family, do we have count model?
-  faminfo <- sjstats::model_family(model)
+  faminfo <- get_model_info(model)
 
-  if (fun == "coxph" && type == "surv") faminfo$is_bin <- TRUE
-
-  # create logical for family
-  binom_fam <- faminfo$is_bin
-  poisson_fam <- faminfo$is_pois
+  if (fun == "coxph" && type == "surv") faminfo$is_binomial <- TRUE
 
   # get model frame
-  fitfram <- sjstats::model_frame(model, fe.only = FALSE)
+  fitfram <- insight::get_data(model)
 
   # expand model frame to grid of unique combinations, if
   # user not requested full data
@@ -580,6 +642,7 @@ ggpredict_helper <- function(model,
     vcov.fun,
     vcov.type,
     vcov.args,
+    condition = condition,
     ...
   )
 
@@ -589,17 +652,16 @@ ggpredict_helper <- function(model,
 
   # for survival probabilities or cumulative hazards, we need
   # the "time" variable
-
-  if (fun == "coxph" && type %in% c("surv", "cumhaz"))
+  if (fun == "coxph" && type %in% c("surv", "cumhaz")) {
     terms <- c("time", terms)
+  }
 
   # get axis titles and labels
   all.labels <- get_all_labels(
     fitfram = ori.mf,
     terms = terms,
     fun = get_model_function(model),
-    binom_fam = binom_fam,
-    poisson_fam = poisson_fam,
+    faminfo = faminfo,
     no.transform = FALSE,
     type = type
   )
@@ -612,7 +674,7 @@ ggpredict_helper <- function(model,
   # now select only relevant variables: the predictors on the x-axis,
   # the predictions and the originial response vector (needed for scatter plot)
 
-  cols.to.keep <- na.omit(match(
+  cols.to.keep <- stats::na.omit(match(
     c(terms, "predicted", "conf.low", "conf.high", "response.level"),
     colnames(fitfram)
   ))
@@ -688,7 +750,6 @@ ggpredict_helper <- function(model,
   # x needs to be numeric
   if (!x.as.factor) mydf$x <- sjlabelled::as_numeric(mydf$x)
 
-
   # add standard errors
   se <- attr(fitfram, "std.error", exact = TRUE)
 
@@ -707,12 +768,26 @@ ggpredict_helper <- function(model,
   # check if outcome is log-transformed, and if so,
   # back-transform predicted values to response scale
 
-  rv <- sjstats::resp_var(model)
-  if (grepl("log\\((.*)\\)", rv)) {
-    mydf$predicted <- exp(mydf$predicted)
-    mydf$conf.low <- exp(mydf$conf.low)
-    mydf$conf.high <- exp(mydf$conf.high)
-    message("Model has log-transformed response. Back-transforming predictions to original response scale.")
+  rv <- insight::find_variables(model)[["response"]]
+
+  if (any(grepl("log\\((.*)\\)", rv))) {
+
+    # do we have log-log models?
+    if (grepl("log\\(log\\((.*)\\)\\)", rv)) {
+      mydf$predicted <- exp(exp(mydf$predicted))
+      if (obj_has_name(mydf, "conf.low") && obj_has_name(mydf, "conf.high")) {
+        mydf$conf.low <- exp(exp(mydf$conf.low))
+        mydf$conf.high <- exp(exp(mydf$conf.high))
+      }
+    } else {
+      mydf$predicted <- exp(mydf$predicted)
+      if (obj_has_name(mydf, "conf.low") && obj_has_name(mydf, "conf.high")) {
+        mydf$conf.low <- exp(mydf$conf.low)
+        mydf$conf.high <- exp(mydf$conf.high)
+      }
+    }
+
+    message("Model has log-transformed response. Back-transforming predictions to original response scale. Standard errors are still on the log-scale.")
   }
 
 
@@ -733,6 +808,13 @@ ggpredict_helper <- function(model,
     faminfo = faminfo,
     x.is.factor = x.is.factor,
     full.data = has.full.data,
-    constant.values = attr(expanded_frame, "constant.values", exact = TRUE)
+    constant.values = attr(expanded_frame, "constant.values", exact = TRUE),
+    terms = cleaned.terms,
+    ori.terms = ori.terms,
+    at.list = get_expanded_data(
+      model = model, mf = ori.mf, terms = ori.terms, typ.fun = typical,
+      condition = condition, pretty.message = FALSE, emmeans.only = TRUE
+    ),
+    n.trials = attr(expanded_frame, "n.trials", exact = TRUE)
   )
 }
