@@ -16,17 +16,21 @@ if (suppressWarnings(
     pr <- ggpredict(fit, "c12hour [20,30,40]")
     p <- plot(pr)
     p <- plot(pr, ci = FALSE)
-    p <- plot(pr, ci = "dot")
+    p <- plot(pr, ci = TRUE, ci.style = "dot")
     p <- plot(pr, rawdata = TRUE)
+    p <- plot(pr, colors = "bw")
+    p <- plot(pr, colors = "gs")
 
     pr <- ggpredict(fit, c("c12hour", "c172code"))
     p <- plot(pr)
     p <- plot(pr, ci = FALSE)
-    p <- plot(pr, ci = "dot")
+    p <- plot(pr, ci = TRUE, ci.style = "dot")
     p <- plot(pr, rawdata = TRUE)
     p <- plot(pr, facets = TRUE)
     p <- plot(pr, facets = FALSE)
     p <- plot(pr, use.theme = FALSE)
+    p <- plot(pr, colors = "bw")
+    p <- plot(pr, colors = "gs")
   })
 
 }
